## Colophon

WORK_TITLE

The work is copyright (c) AUTHOR, YEAR. RIGHTS.

AUTHOR_URL

PUBLICATION_RIGHTS

Published by PUBLISHER.

CONTRIBUTORS

The text features the PT Sans and PT Serif fonts, created in 2009 by Paratype, and are released under SIL Open Font License.

The Chapisha and Qwyre Publishing logo is copyright (c) Whythawk, 2015. All rights reserved.

This is a work of fiction and, except in the case of historical fact, any resemblance to actual persons, living or dead, is purely coincidental.
Every effort has been made to obtain the necessary permissions with reference to copyright material, both illustrative and quoted. We apologise for any omissions in this respect and will be pleased to make appropriate acknowledgements in any future edition.

This ebook was generated by chapisha, an open-source toolkit allowing you to convert .docx documents into standards-compliant EPUB 3 electronic books. The software is developed and maintained by Qwyre Publishing.

Chapisha is the Swahili word for 'publish' or 'post'.